==> ulyxex.0.0.6.with-tinyMce.zip: pages/code/admin_user_modify.php <==
<?php
class UserModify extends Admin {
	function __construct() {
		$this->h = New Html();
		$this->tr = New Translate();
	}
	public function update_user($userId) {
		/* check is login is in use */
		// $query = "SELECT ID FROM ".USERS." WHERE LOGIN = '".$this->h->safe($_POST['userlogin'])."'";
		// $query = $this->q($query);
		// if (@mysql_fetch_assoc($query)) return $this->h->h3("login in use !");
		/* update user */
		if (!empty($_POST['password']) && $_POST['password'] != $_POST['confirm']) {
			$result = $this->h->h3($this->tr->w("error password !"));
		} else if ($this->h->num($_POST['level']) < $_SESSION['level']) {
			$result = $this->h->h3($this->tr->w("wrong level !"));
		} else if ($_POST['userlogin'] == "") {
			$result = $this->h->h3($this->tr->w("login field empty !"));
		} else {
			$query = "UPDATE ".USERS." SET LOGIN = '".$this->h->safe($_POST['userlogin'])."'".
										",USERNAME = '".$this->h->safe($_POST['username'])."'".
										",DESCRIPTION = '".$this->h->safe($_POST['description'])."'".
										",MAIL = '".$this->h->safe($_POST['mail'])."'".
										",LOGIN = '".$this->h->safe($_POST['userlogin'])."'".
										",USERLEVEL = ".$this->h->num($_POST['level']);
			if (!empty($_POST['password'])) $query .=	",PASSWORD = '".$this->h->crypt($_POST['password'])."'";
			$query .=						" WHERE ID = ".$userId;
			$query = $this->q($query);
			$result = $this->h->h3($this->tr->ws("user").strip_tags($_POST['username']).$this->tr->wsp("updated !"));
		}
		return $result;
	}
	public function data_user($userId) {
		$query = "SELECT * FROM ".USERS." WHERE ID = ".$userId.";";
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		if ($dat['USERLEVEL'] < $_SESSION['level']) return  $this->h->h2("error level");
		if ($_SESSION['level'] > 2 && $dat['USEROWNER'] =! $_SESSION['userid']) return $this->h->h2("error owner");
		$siteDat = $this->home_params();
		$content = $this->h->input("hidden","update",1);
		$content .= $this->h->input("hidden","user_id",$dat['ID']);
		$content .= $this->h->p($this->tr->ws("login").$this->h->input("text","userlogin",$dat['LOGIN'],"readonly"));
		$content .= $this->h->p($this->tr->ws("password").$this->h->input("password","password"));
		$content .= $this->h->p($this->tr->ws("confirm password").$this->h->input("password","confirm"));
		if ($userId == 1) {
			$content .= $this->h->input("hidden","level",$dat['ID']);
		} else {
			$levels = array();
			for ($i=0;$i < (5 - $_SESSION['level']);$i++) {
				$x = 4 - $i;
				$levels["level ".$x] =  $x;
			}
			$content .= $this->h->p($this->tr->w("level").$this->h->select($levels,"level",$dat['USERLEVEL']));
		}
		$content .= $this->h->p($this->tr->ws("name").$this->h->input("text","username",htmlentities($dat['USERNAME'])));
		$content .= $this->h->p($this->tr->w("description")).$this->h->p($this->h->textarea($dat['DESCRIPTION'],"description",array(8,FIELDWIDTH)));
		$content .= $this->h->p($this->tr->ws("mail").$this->h->input("text","mail",$dat['MAIL']));
		$content .= $this->h->p($this->h->input("submit","save",$this->tr->w("update")));
		$result = $this->h->form($content ,"user","post","admin.php?action=modify_user");
		return $result;
	}
}
?>

==> ulyxex.0.0.8.with-tinyMce.zip: pages/code/admin_user_modify.php <==
<?php
class UserModify extends Admin {
	function __construct() {
		$this->h = New Html();
		$this->tr = New Translate();
	}
	public function update_user($userId) {
		/* not check if login is in use because login is read only */
		/* update user */
		if (!empty($_POST['password']) && $_POST['password'] != $_POST['confirm']) {
			$result = $this->h->h3($this->tr->w("error password !"));
		} else if ($this->h->num($_POST['level']) < $_SESSION['level']) {
			$result = $this->h->h3($this->tr->w("wrong level !"));
		} else if ($_POST['userlogin'] == "") {
			$result = $this->h->h3($this->tr->w("login field empty !"));
        } else if ($userId == 1 && $_SESSION['userid'] != 1) { 
            $result = $this->h->h3($this->tr->w("only admin can modify admin !"));
		} else {
			$query = "UPDATE ".USERS." SET LOGIN = '".$this->h->safe($_POST['userlogin'])."',".
										"USERNAME = '".$this->h->safe($_POST['username'])."',".
										"DESCRIPTION = '".$this->h->safe($_POST['description'])."',".
										"MAIL = '".$this->h->safe($_POST['mail'])."',".
										"LOGIN = '".$this->h->safe($_POST['userlogin'])."',".
										"USERLEVEL = ".$this->h->num($_POST['level']);
			if (!empty($_POST['password'])) $query .=	",PASSWORD = '".$this->h->crypt($_POST['password'])."'";
			$query .=					" WHERE ID = ".$userId;
			$query = $this->q($query);
			$result = $this->h->h3($this->tr->ws("user").strip_tags($_POST['username']).$this->tr->wsp("updated !"));
		}
		return $result;
	}
	public function data_user($userId) {
		$query = "SELECT * FROM ".USERS." WHERE ID = ".$userId.";";
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		if ($dat['USERLEVEL'] < $_SESSION['level']) return  $this->h->h2("error level");
		if ($_SESSION['level'] > 2 && $dat['USEROWNER'] =! $_SESSION['userid']) return $this->h->h2("error owner");
		$siteDat = $this->home_params();
		$content = $this->h->input("hidden","update",1);
		$content .= $this->h->input("hidden","user",$dat['ID']);
		$content .= $this->h->p($this->tr->ws("login").$this->h->input("text","userlogin",$dat['LOGIN'],"readonly"));
		$content .= $this->h->p($this->tr->ws("password").$this->h->input("password","password"));
		$content .= $this->h->p($this->tr->ws("confirm password").$this->h->input("password","confirm"));
		if ($userId == 1) {
			$content .= $this->h->input("hidden","level",$dat['ID']);
		} else {
			$levels = array();
			for ($i=0;$i < (5 - $_SESSION['level']);$i++) {
				$x = 4 - $i;
				$levels["level ".$x] =  $x;
			}
			$content .= $this->h->p($this->tr->w("level").$this->h->select($levels,"level",$dat['USERLEVEL']));
		}
		$content .= $this->h->p($this->tr->ws("name").$this->h->input("text","username",htmlentities($dat['USERNAME'])));
		$content .= $this->h->p($this->tr->w("description")).$this->h->p($this->h->textarea($dat['DESCRIPTION'],"description",array(8,FIELDWIDTH)));
		$content .= $this->h->p($this->tr->ws("mail").$this->h->input("text","mail",$dat['MAIL']));
		$content .= $this->h->p($this->h->input("submit","save",$this->tr->w("update")));
		$result = $this->h->form($content ,"user","post","admin.php?action=modify_user");
		return $result;
	}
}
?>
